<?php
/**
 * Pro customizer section.
 *
 * @since  2.0.0
 * @access public
 */
class CB_Customize_Section_Pro extends WP_Customize_Section {

	/**
	 * The type of customize section being rendered.
	 *
	 * @since  1.0.0
	 * @access public
	 * @var    string
	 */
	public $type = 'theme-pro';

	/**
	 * Custom button text to output.
	 *
	 * @since  1.0.0
	 * @access public
	 * @var    string
	 */
	public $pro_text = '';

	/**
	 * Custom pro button URL.
	 *
	 * @since  1.0.0
	 * @access public
	 * @var    string
	 */
	public $pro_url = '';

	/**
	 * Add custom parameters to pass to the JS via JSON.
	 *
	 * @since  1.0.0
	 * @access public
	 */
	public function json() {
		$json = parent::json();

		$json['pro_text'] = $this->pro_text;
		$json['pro_url']  = esc_url( $this->pro_url );

		return $json;
	}

	/**
	 * Render template.
	 */
	public function render() {
		$pro_url  = esc_url( $this->pro_url );
		$pro_text = esc_html( $this->pro_text );
		?>

		<li id="accordion-section-<?php echo esc_attr( $this->id ); ?>" class="accordion-section control-section control-section-<?php echo esc_attr( $this->type ); ?> cannot-expand">

			<h3 class="accordion-section-title">
				<?php echo esc_html( $this->title ); ?>
				<?php
				if ( $this->pro_text && $this->pro_url ) {
					echo "<a href='{$pro_url}' class='wp-ui-text-highlight' target='_blank'>{$pro_text}</a>";
				}
				?>
			</h3>
		</li>
	<?php
	}
}