<?php
/**
 * Advance Settings Panel customize settings.
 *
 * @package    Community_Builder
 * @subpackage Customizer\Panels
 * @copyright  Copyright (c) 2018, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh
 */

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

/**
 * Advance Panel helper.
 */
class CB_Customize_Panel_Settings_Advance {

	/**
	 * Panel id.
	 *
	 * @var string
	 */
	private $panel = 'cb_setting-advance';

	/**
	 * CB_Customize_Panel_Settings_Advance constructor.
	 */
	public function __construct() {
		add_filter( 'cb_customizer_sections', array( $this, 'add_sections' ) );
	}

	/**
	 * Add sections for this panel.
	 *
	 * @param array $sections sections.
	 *
	 * @return array
	 */
	public function add_sections( $sections ) {

		$new_sections = $this->get_sections();

		return array_merge( $sections, $new_sections );
	}

	/**
	 * Get all sections for this panel.
	 *
	 * @return array
	 */
	public function get_sections() {

		$panel             = $this->panel;
		$settings_sections = array();

		$settings_sections['setting-misc'] = array(
			'panel'   => $panel,
			'title'   => __( 'Miscellaneous', 'community-builder' ),
			'options' => array(

				'enable-editor-style' => array(
					'setting' => array(
						'sanitize_callback' => 'absint',
						'transport'         => 'refresh',
						'default'           => cb_get_default( 'enable-editor-style' ),
					),
					'control' => array(
						'type'        => 'checkbox',
						'input_attrs' => array(),
						'label'       => __( 'Enable Editor style?', 'community-builder' ),
						'description' => __( 'You can enable/disable the post editor style using this option.', 'community-builder' ),
					),
				),

				'enable-textarea-autogrow'    => array(
					'setting' => array(
						'sanitize_callback' => 'absint',
						'transport'         => 'refresh',
						'default'           => cb_get_default( 'enable-textarea-autogrow' ),
					),
					'control' => array(
						'type'        => 'checkbox',
						'input_attrs' => array(),
						'label'       => __( 'Enable text box auto grow?', 'community-builder' ),
						'description' => __( 'If you enable it, instead of showing scrollbars, the textarea height will be adjusted to the content.', 'community-builder' ),
					),
				),
			), // end of options.
		);


		$settings_sections['asset-loading'] = array(
			'panel'   => $panel,
			'title'   => __( 'Asset Loading', 'community-builder' ),
			'options' => array(
				'load-fa' => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_int' ),
						'transport'         => 'refresh',
						'default'           => cb_get_default( 'load-fa' ),
					),
					'control' => array(
						'type'        => 'checkbox',
						'input_attrs' => array(),
						'label'       => __( 'Load FontAwesome?', 'community-builder' ),
						'description' => __( 'Load FontAwesome Css. You can disable it here if it is already loaded by some plugin etc.', 'community-builder' ),
					),
				),

				'load-fa-cdn'      => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_int' ),
						'transport'         => 'refresh',
						'default'           => cb_get_default( 'load-fa-cdn' ),
					),
					'control' => array(
						'type'        => 'checkbox',
						'input_attrs' => array(),
						'label'       => __( 'Load FontAwesome from CDN?', 'community-builder' ),
						'description' => __( 'If you enable this, FontAwesome will be loaded from bootstrap cdn. If you disable it, It will be loaded from local copy.', 'community-builder' ),
					),
				),
				'load-google-font' => array(
					'setting' => array(
						'sanitize_callback' => array( 'CB_Data_Sanitizer', 'sanitize_int' ),
						'transport'         => 'refresh',
						'default'           => cb_get_default( 'load-google-font' ),
					),
					'control' => array(
						'type'        => 'checkbox',
						'input_attrs' => array(
							'default' => 1,
						),
						'label'       => __( 'Load Google Fonts?', 'community-builder' ),
						'description' => __( 'If you disable this, Google Fonts will not be loaded.', 'community-builder' ),
					),
				),
			),
		);

		return apply_filters( 'cb_customizer_advance_sections', $settings_sections );
	}

} // end of class.

new CB_Customize_Panel_Settings_Advance();
